==> 1.1.0.tar.gz: lib/dom/css_capable.dart <==
part of dom_node;

/**
 * This class allows operating with CSS attributes.
 */
abstract class DomNodeCssCapable {
  /**
   * Gets the internal elemeents.
   */
  List<Element> get elements;
  
  /**
   * Gets or sets a CSS attribute.
   */
  String css(String name, [String value]) {
    if (value != null) {
      _setCssAttribute(name, value);
    }
    
    return _getCssAttribute(name);
  }
  
  /**
   * Sets a CSS attribute.
   */
  void _setCssAttribute(String name, String value) {
    elements.forEach((element) {
      var attrs = _getCssAttributesMap(element);
      
      attrs[name] = value;
      _setCssAttributesMap(element, attrs);
    });
  }
  
  /**
   * Gets a CSS attribute.
   */
  String _getCssAttribute(String name) {
    var ret = '';
    
    if (elements.length > 0) {
      var attrs = _getCssAttributesMap(elements[0]);
      
      name = name.toLowerCase();
      if (attrs.containsKey(name)) {
        ret = attrs[name];
      }
    }
    
    return ret;
  }
  
  /**
   * Gets the list of attributes of an element.
   */
  Map<String, String> _getCssAttributesMap(Element element) {
    var ret = {};
    var css = element.getAttribute('style');
    
    if (css != null) {
      css.split(';').forEach((cssAttr) {
        var item = cssAttr.split(':');
        var key = item.length > 0? item[0].trim().toLowerCase() : '';
        var value = item.length > 1? item[1].trim() : '';
        
        if (key.length > 0 && value.length > 0) {
          ret[key] = value;
        }
      });
    }
    
    return ret;
  }
  
  /**
   * Sets the list of attributes of an element.
   */
  void _setCssAttributesMap(Element element, Map<String, String> attrs) {
    var arr = [];
    
    attrs.keys.forEach((key) {
      if (key != null && key.length > 0) {
        arr.add(key.toLowerCase() + ': ' + attrs[key]);
      }
    });
    
    element.setAttribute('style', arr.join(''));
  }
}

==> 1.1.3.tar.gz: lib/dom/css_capable.dart <==
part of dom_node;

/**
 * This class allows operating with CSS attributes.
 */
abstract class DomNodeCssCapable {
  /**
   * Gets the internal elemeents.
   */
  List<Element> get elements;
  
  /**
   * Gets or sets a CSS attribute.
   */
  String css(String name, [String value]) {
    if (value != null) {
      _setCssAttribute(name, value);
    }
    
    return _getCssAttribute(name);
  }
  
  /**
   * Sets a CSS attribute.
   */
  void _setCssAttribute(String name, String value) {
    elements.forEach((element) {
      var attrs = _getCssAttributeMap(element);
      
      attrs[name] = value;
      _setCssAttributeMap(element, attrs);
    });
  }
  
  /**
   * Gets a CSS attribute.
   */
  String _getCssAttribute(String name) {
    var ret = '';
    
    if (elements.length > 0) {
      var attrs = _getCssAttributeMap(elements[0]);
      
      name = name.toLowerCase();
      if (attrs.containsKey(name)) {
        ret = attrs[name];
      }
    }
    
    return ret;
  }
  
  /**
   * Gets the list of attributes of an element.
   */
  Map<String, String> _getCssAttributeMap(Element element) {
    var ret = {};
    var css = element.getAttribute('style');
    
    if (css != null) {
      css.split(';').forEach((cssAttr) {
        var item = cssAttr.split(':');
        var key = item.length > 0? item[0].trim().toLowerCase() : '';
        var value = item.length > 1? item[1].trim() : '';
        
        if (key.length > 0 && value.length > 0) {
          ret[key] = value;
        }
      });
    }
    
    return ret;
  }
  
  /**
   * Sets the list of attributes of an element.
   */
  void _setCssAttributeMap(Element element, Map<String, String> attrs) {
    var arr = [];
    
    attrs.keys.forEach((key) {
      if (key != null && key.length > 0) {
        arr.add(key.toLowerCase() + ': ' + attrs[key]);
      }
    });
    
    element.setAttribute('style', arr.join(''));
  }
}
